@@ -42,7 +42,7 @@ def _setattr(model, attr, value):
     attr_split = attr.split('.')
     if len(attr_split) > 1:
         model = getattr(model, attr_split[0])
-        return _setattr(model, '.'.join(attr_split[1:], value))
+        return _setattr(model, '.'.join(attr_split[1:]), value)
     setattr(model, attr_split[0], value)
 
 
